/*#############################################################
File Name       : ex2_HC06_leds.c
Author          : Grant Phillips
Date Modified   : 06/08/2014
Compiler        : Keil ARM-MDK (uVision V4.70.0.0)
Tested On       : STM32F3-Discovery

Description     : Example program that uses the UART5 module to 
									establish a serial link via a HC-06 Bluetooth
									module with another device.  If the STM32F3
									receives the following character:
									"A"		-	North LED ON
									"B"		-	North LED OFF
									"C"		-	NE LED ON
									"D"		-	NE LED OFF
									"E"		-	E LED ON
									"F"		-	E LED OFF
									"G"		-	SE LED ON
									"H"		-	SE LED OFF
									"I"		-	S LED ON
									"J"		-	S LED OFF
									"K"		-	SW LED ON
									"L"		-	SW LED OFF
									"M"		-	W LED ON
									"N"		-	W LED OFF
									"O"		-	NW LED ON
									"P"		-	NW LED OFF

Requirements    : * STM32F3-Discovery Board
									* Make sure the HC06_F3.c file is in the 
                    same folder than the project
              
Circuit         : * 8 LEDs connected to PE15 - PE8 (LD3 - LD10 
                    ON STM32F3-DISCOVERY BOARD)
									* HC06 Bluetooth module is connected as follows:
										TXD			-		PD2
										RXD			-		PC12
										GND			-		GND
										VCC			-		3.3V
									
See the STM32F3-Discovery User Manual (UM1570) for the block 
diagram of the STM32F303VCT6 processor (p13), a summary of
the GPIO connections (p21-29) and the schematic diagram (p31-34)

##############################################################*/

/* #includes -------------------------------------------------*/
#include "main.h"																								//main library to include for device drivers, peripheral drivers, etc.
#include "HC06_F3.c"																						//for the HC06 functions on the STM32F3-Discovery

/* #defines --------------------------------------------------*/

/* #function prototypes --------------------------------------*/
void InitLEDs(void);																					  //prototype for the user function to initialize the USER LEDs

/* #global variables -----------------------------------------*/
GPIO_InitTypeDef        GPIO_InitStructure;											//structure used for setting up a GPIO port
RCC_ClocksTypeDef 			RCC_Clocks;															//structure used for setting up the SysTick Interrupt



// Unused global variables that have to be included to ensure correct compiling */
// ###### DO NOT CHANGE ######
// ===============================================================================
__IO uint32_t TimingDelay = 0;																	//used with the Delay function
__IO uint8_t DataReady = 0;
__IO uint32_t USBConnectTimeOut = 100;
__IO uint32_t UserButtonPressed = 0;
__IO uint8_t PrevXferComplete = 1;
// ===============================================================================



int main(void)
{
	/* Set the SysTick Interrupt to occur every 1ms) */
	RCC_GetClocksFreq(&RCC_Clocks);
	if (SysTick_Config(RCC_Clocks.HCLK_Frequency / 1000))
		while(1);																										//will end up in this infinite loop if there was an error with Systick_Config
	
	HC06_Init(115200);																						//initialize the HC-06 module at 115200 baud
	InitLEDs();																									  //initialize the USER LEDs for this application
	
	HC06_ClearRxBuffer();																					//clear the rx buffer after initialization
		
	/* Main program loop */
  while (1)
  {
		if(new_HC06_msg)															//check if there is a new message
		{
			if(strcmp(HC06_msg, "A") == 0)							//N LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_9, Bit_SET);
			else if(strcmp(HC06_msg, "B") == 0)					//N LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_9, Bit_RESET);
			else if(strcmp(HC06_msg, "C") == 0)					//NE LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_10, Bit_SET);
			else if(strcmp(HC06_msg, "D") == 0)					//NE LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_10, Bit_RESET);
			else if(strcmp(HC06_msg, "E") == 0)					//E LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_11, Bit_SET);
			else if(strcmp(HC06_msg, "F") == 0)					//E LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_11, Bit_RESET);
			else if(strcmp(HC06_msg, "G") == 0)					//SE LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_12, Bit_SET);
			else if(strcmp(HC06_msg, "H") == 0)					//SE LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_12, Bit_RESET);
			else if(strcmp(HC06_msg, "I") == 0)					//S LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_13, Bit_SET);
			else if(strcmp(HC06_msg, "J") == 0)					//S LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_13, Bit_RESET);
			else if(strcmp(HC06_msg, "K") == 0)					//SW LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_14, Bit_SET);
			else if(strcmp(HC06_msg, "L") == 0)					//SW LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_14, Bit_RESET);
			else if(strcmp(HC06_msg, "M") == 0)					//W LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_15, Bit_SET);
			else if(strcmp(HC06_msg, "N") == 0)					//W LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_15, Bit_RESET);
			else if(strcmp(HC06_msg, "O") == 0)					//NW LED ON
				GPIO_WriteBit (GPIOE, GPIO_Pin_8, Bit_SET);
			else if(strcmp(HC06_msg, "P") == 0)					//NW LED OFF
				GPIO_WriteBit (GPIOE, GPIO_Pin_8, Bit_RESET);
			else
				HC06_PutStr("Incorrect command\n");				//Reply incorrect command
				
			new_HC06_msg=0;															//clear message flag
		}
  }	
}



void InitLEDs(void)
{
	GPIO_InitTypeDef        GPIO_InitStructure;										//structure used for setting up a GPIO port
	
  /* GPIOE Periph clock enable */
  RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOE, ENABLE);           
  
  /* Configure PE15 - PE8 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15 | GPIO_Pin_14 | GPIO_Pin_13 | GPIO_Pin_12 | GPIO_Pin_11 | GPIO_Pin_10 | GPIO_Pin_9 | GPIO_Pin_8;   //which pins to setup, seperated by |
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;               
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;                       
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;                    
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;                     
  GPIO_Init(GPIOE, &GPIO_InitStructure);                                    
}



/*
Retarget the C library printf function to the SWO Viewer.
Overwrites int fputc(int ch, FILE *f) function used by printf.
*/								
int fputc(int ch, FILE *f)
{
	return(ITM_SendChar(ch));
}






// -------------------------------------------------------------------------------

// Function to insert a timing delay of nTime
// ###### DO NOT CHANGE ######
void Delay(__IO uint32_t nTime)
{
  TimingDelay = nTime;

  while(TimingDelay != 0);
}

// Function to Decrement the TimingDelay variable.
// ###### DO NOT CHANGE ######
void TimingDelay_Decrement(void)
{
  if (TimingDelay != 0x00)
  { 
    TimingDelay--;
  }
}

// Unused functions that have to be included to ensure correct compiling
// ###### DO NOT CHANGE ######
// =======================================================================
uint32_t L3GD20_TIMEOUT_UserCallback(void)
{
  return 0;
}

uint32_t LSM303DLHC_TIMEOUT_UserCallback(void)
{
  return 0;
}
// =======================================================================



